#!/bin/sh

####################################################################
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
# 5698-WSH
# (C) Copyright IBM Corp. 1998, 2006 All Rights Reserved.
###################################################################

#------------ Backup Function ------------

#------------ parameter   ------------
#TwsBackAction.sh <TWS home path>
#                 <backup path>
#		  <file containing the list of executable files>
#		  <file containing the list of configuration files>
#		  <verbose parameter>
#		  <parameter for: 1. restoring back an existing backup>

#------------ exit value  ------------
#  1     "The backup process is not able to create the backup directory"
#  2     "The file containing the list of executable files is missing"
#  3     "The file containing the list of configuration files is missing"
#  4     "Change directory to TWS home path Failed"

CMD_LINE_ARGS=$*; export CMD_LINE_ARGS
#for ACT_ARG in $CMD_LINE_ARGS

#do
#  echo "PARAMETER:<$ACT_ARG>"
#done

#echo "twsBackupActionIsWorking........"



#set -vx

#------- get the parametres from the caller -------
  TWS_PREV_INST_DIR="$1"
  SAVE_DIR="$2"
  SAVE_FILE_LIST="$3"
  CFG_FILE_LIST="$4"
  verbose="$5"
  ACTION="$6"

# ACTION is blank for backup request,
# ACTION values RESTORE for backup restore

#------- set needed variables -------
  TWS_END_DIR="`basename $TWS_PREV_INST_DIR`"
  PATH_OF_END_DIR="`dirname $TWS_PREV_INST_DIR`"
  FIRST_FILE="YES"
  REST_ACT_DIR=""
  SAVE_RC=0
  MAX_ERR_LEV=0
  ENV_UMASK=`umask`
  TEST_ERR_FILE="${TWS_PREV_INST_DIR}/updt_tws_82.err"
  FLAG=0
  COMPRESS_EXT=".Z";export COMPRESS_EXT

#------- verify the presence of the backup list file   --------
#echo "#------- verify the presence of the backup list file"

  if [ ! -f ${SAVE_FILE_LIST} ]
  then
    if [ "$verbose" = "-verbose" ]
    then
    echo "xxx #The list file ${SAVE_FILE_LIST} is missing." >&2
    fi
    exit 2
  fi


#------- verify the presence of the backup list file   --------
#echo "#------- verify the presence of the backup list file"

  if [ ! -f ${CFG_FILE_LIST} ]
  then
    if [ "$verbose" = "-verbose" ]
    then
    echo "xxx #The list file ${CFG_FILE_LIST} is missing." >&2
    fi
    exit 3
  fi


#------- calculate the directory where make the tar file -------
#------- make it if missing and verify the result of the --------
#------- operation                                      --------
#echo "#------- make it if missing and verify"


if [ "$ACTION" = "" ]
then
  if [ ! -d "$SAVE_DIR" ]
  then
    mkdir -p "$SAVE_DIR"
  fi

  if [ ! -d "$SAVE_DIR" ]
  then
  if [ "$verbose" = "-verbose" ]
    then
        echo "xxx #The backup process is not able to create the ${SAVE_DIR} directory." >&2
    fi
    exit 1
  fi

  chmod 755 "$SAVE_DIR"
fi

if [ "$ACTION" = "RESTORE" ]
then
  if [ ! -d "$SAVE_DIR" ]
  then
  if [ "$verbose" = "-verbose" ]
    then
        echo "xxx #The script is not able to locate the ${SAVE_DIR} directory." >&2
    fi
    exit 1
  fi
fi


#------- move the process to the TWS home directory and  -------
#------- verify the result of the operation              -------

  cd ${TWS_PREV_INST_DIR}


# ***************************
# BACKUP FILES
# ***************************
if [ "$ACTION" = "" ]
then

#------- for each files or directory listed in the   -------
#------- Backup list file save it in the tar file    -------
#------- and verify the result of the operation      -------
#echo "#-------  Backup list file save it in the tar file             -------"
  cat ${SAVE_FILE_LIST} | while read file_to_save
  do
    if [ -f $file_to_save -o -d $file_to_save ]
    then
      if [ "$FIRST_FILE" = "YES" ]
      then
	tar cf "${SAVE_DIR}"/backup $file_to_save
        SAVE_RC=$?
        if [ $SAVE_RC -ne 0 ]
        then
          echo "WARNING :An Error occurred making the tar file needed for the Backup of the previous installation."
        fi
        FIRST_FILE="NO"
      else
	tar rf "${SAVE_DIR}"/backup $file_to_save
        SAVE_RC=$?
        if [ $SAVE_RC -ne 0 ]
        then
	  echo "WARNING :An Error occurred making the tar file needed for the Backup of the previous installation."
        fi
      fi
    fi
  done


  cat ${CFG_FILE_LIST} | while read file_to_save
  do

       PATH_OF_FILE="`dirname $file_to_save`"
#       echo "${SAVE_DIR}/${PATH_OF_FILE}"
       if [ ! -d "${SAVE_DIR}"/${PATH_OF_FILE} ]
       then
         umask 022
         mkdir -p  "${SAVE_DIR}"/${PATH_OF_FILE}
         if [ ! -d "${SAVE_DIR}"/${PATH_OF_FILE} ]
         then
           echo "WARNING : The backup process was not able to create the ${SAVE_DIR}/${TWS_END_DIR}/${PATH_OF_FILE} directory."
           MAX_ERR_LEV=2
         fi
         umask ${ENV_UMASK}
       fi
    if [ -f ${TWS_PREV_INST_DIR}/$file_to_save ]
    then
       cp -p ${TWS_PREV_INST_DIR}/$file_to_save "${SAVE_DIR}"/${PATH_OF_FILE}
       SAVE_RC=$?
       if [ ${SAVE_RC} -ne 0 ]
       then
         #echo "WARNING : The backup process was not able to copy $file_to_save into  ${SAVE_DIR}/${PATH_OF_FILE}/${file_to_save} directory."
          MAX_ERR_LEV=2
        fi
     fi
  done

#------- compress the Backup tar file            -------
#------- and verify the result of the operation  -------
#- use the compression tool supported by the Platform -
#echo "#-------compress the Backup tar file            -------"

 if [ "$COMPRESS_TOOL" = "" ]
 then
     compress -f "${SAVE_DIR}"/backup
     SAVE_RC=$?
  else
     $COMPRESS_TOOL -f "${SAVE_DIR}"/backup
     SAVE_RC=$?
  fi

  if [ $SAVE_RC -ne 0 ]
  then
    echo "A warning occurred compressing the tar file needed for the Backup of the previous installation."
  fi

fi



# ***************************
# RESTORING A BACKUP DIR
# ***************************
if [ "$ACTION" = "RESTORE" ]
then
  
  SAVE_FILE_TAR="${SAVE_DIR}"/backup

  #- use the uncompression tool supported by the Platform -  
  if [ ! -f ${SAVE_FILE_TAR} ]
  then
    if [ "$COMPRESS_TOOL" = "" ]
    then
       uncompress ${SAVE_FILE_TAR}
       ## uncompress ${SAVE_FILE_TAR}${COMPRESS_EXT}
    else
       $COMPRESS_TOOL -d ${SAVE_FILE_TAR}
       ## $COMPRESS_TOOL -d ${SAVE_FILE_TAR}${COMPRESS_EXT}
    fi  
  fi

  if [ ! -f ${SAVE_FILE_TAR} ]
  then
    echo "The uncompress operation of Backup file ${SAVE_FILE_TAR}${COMPRESS_EXT} failed."
    return 1
  fi

  RC_REST=0
  tar xpf ${SAVE_FILE_TAR}
  RC_REST=$?
  if [ $RC_REST -ne 0 ]
  then
      echo "An error occurred during the untar of the ${SAVE_FILE_TAR} Backup file"
  fi 


  # Restoring Configuration Files
  cat ${CFG_FILE_LIST} | while read file_to_save
  do
       # Checking creating the directory of the file to restore
       PATH_OF_FILE="`dirname $file_to_save`"

       if [ ! -d "${TWS_PREV_INST_DIR}"/${PATH_OF_FILE} ]
       then
         umask 022
         mkdir -p  "${TWS_PREV_INST_DIR}"/${PATH_OF_FILE}
         if [ ! -d "${TWS_PREV_INST_DIR}"/${PATH_OF_FILE} ]
         then
           echo "WARNING : The backup process was not able to create the ${SAVE_DIR}/${TWS_END_DIR}/${PATH_OF_FILE} directory."
         fi
         umask ${ENV_UMASK}
       fi

    if [ -f "${SAVE_DIR}"/$file_to_save ]
    then
       cp -p "${SAVE_DIR}"/$file_to_save ${TWS_PREV_INST_DIR}/$file_to_save
       SAVE_RC=$?
       if [ ${SAVE_RC} -ne 0 ]
       then
         echo "WARNING : The backup process was not able to copy ${SAVE_DIR}/${PATH_OF_FILE} into ${TWS_PREV_INST_DIR}/$file_to_save directory."
       fi
     fi

  done



fi


  exit 0

