#!/bin/sh
####################################################################
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
# 5698-WSH
# (C) Copyright IBM Corp. 1998, 2006 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###################################################################

#------- get the parametres from the caller -------
MAIN_DIR="$1"
INSTALL_DIR="$2"
MAEUSER="$3"
MAEPASSWORD="$4"
TWS_CPUTYPE="$5"
TWS_MASTER="$6"
TWS_THISCPU="$7"
SD_INST_LOG_FILE="$8"
VERBOSE="$9"
          
OS=`uname -s`;export OS
SD_CLI_DIR=$MAIN_DIR/CLI
SD_WCONVCAT_DIR=$MAIN_DIR/WCONVCAT
ACTIONTOOLS_DIR=$MAIN_DIR/ACTIONTOOLS 
TWSREGISTRYFILE=/etc/TWS/TWSRegistry.dat
STATUSDIR=$INSTALL_DIR/_uninstall/ACTIONTOOLS

BACKUPLOCALPATHVAR="$PATH"

# Vars fo CM execution
LD_LIBRARY_PATH=""; export LD_LIBRARY_PATH
LIBPATH=""; export LIBPATH
SHLIB_PATH=""; export SHLIB_PATH

#TWSRegistry
DIRTWSREGISTRYFILE=/etc/TWS
if [ ! -d "$DIRTWSREGISTRYFILE" ]
  then
    echo "create TWSREGISTRYFILE DIR "
    mkdir "$DIRTWSREGISTRYFILE"
    else
    echo "TWSREGISTRYFILE DIR exist"
fi

#Component
if [ -z "$UNISON_COMPONENT_FILE" ]
then
  UNISON_COMPONENT_FILE="/usr/unison/components"; export UNISON_COMPONENT_FILE
fi
echo "UNISON_COMPONENT_FILE=$UNISON_COMPONENT_FILE"

case $OS in
   AIX)
     INST_INTERP="AIX"; export INST_INTERP
   ;;
   HP-UX)
     case `uname -m` in
     ia64)
       INST_INTERP="HPIA64"; export INST_INTERP
       ;;
     *)
       INST_INTERP="HP"; export INST_INTERP
       ;;
     esac
   ;;
   Linux)
     case `uname -m` in
     *86*)
       INST_INTERP="LINUX_I386"; export INST_INTERP
       ;;
     *390*)
       INST_INTERP="LINUX_S390"; export INST_INTERP
       ;;
     ppc*)
       INST_INTERP="LINUX_PPC"; export INST_INTERP
       ;;
     *)
       INST_INTERP="Linux"; export INST_INTERP
       ;;
     esac
   ;;
   SunOS)
     case `uname -m` in
     *86*)
         INST_INTERP="SOLARIS_I386"; export INST_INTERP
     ;;
     *)
         INST_INTERP="SOLARIS"; export INST_INTERP
     ;;                                       
     esac
   ;;
   IRIX64)
     INST_INTERP="IRIX64"; export INST_INTERP
   ;;
   OSF1)
     INST_INTERP="OSF1";   export INST_INTERP
   ;;
   DYNIX/ptx)
     INST_INTERP="DYNIX";   export INST_INTERP
   ;;
   *)
     INST_INTERP="LINUX_I386"; export INST_INTERP
   ;;
esac

if [ "$VERBOSE" != "-verbose" ]
then
  VERBOSE=""
fi

echo "twsCommitActionInProgress...."
echo "MAIN_DIR=$MAIN_DIR"
echo "INSTALL_DIR=$INSTALL_DIR"
echo "MAEUSER=$MAEUSER"
echo "MAEPASSWORD=********"
# Possible values: SA FTA MDM BKM
echo "TWS_CPUTYPE=$TWS_CPUTYPE"
echo "TWS_MASTER=$TWS_MASTER"
echo "TWS_THISCPU=$TWS_THISCPU"
echo "INST_INTERP=$INST_INTERP"
echo "ACTIONTOOLS_DIR=$ACTIONTOOLS_DIR"
echo "SD_INST_LOG_FILE=$SD_INST_LOG_FILE"
echo "SD_CLI_DIR=$SD_CLI_DIR"
echo "SD_WCONVCAT_DIR=$SD_WCONVCAT_DIR"
echo "VERBOSE=$VERBOSE"

if [ -z "$MAEUSER" ]
then
  exit 1
fi


#
# execute_command is used to execute a command and capture errors.
#
# Arguments:
#	<command> args
execute_command()
{
 $@
 exitValue=$?
 if [ $exitValue -ne 0 ]
 then
   if [ "$VERBOSE" != "-verbose" ]
   then
     echo "The following command failed: $@." >&2
   else
     echo "$@." >&2
   fi

   PATH="$BACKUPLOCALPATHVAR"
   exit $exitValue
 fi
}


#
#
# Start of Main Script Logic.
#

cd ${INSTALL_DIR}
PATH="$BACKUPLOCALPATHVAR"

# TWS environment
. ./tws_env.sh



# Copy old security file if migrating an instance pre 8.2
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Patch: NO


if [ -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
then
	if [ ! -f "$STATUSDIR/8.2_DISCOVERY.historyFile" ]
	then
		if [ ! -f "$STATUSDIR/8.2.1_DISCOVERY.historyFile" ]
		then
			if [ -f "../unison/Security" ]
			then
				if [ -f "$INSTALL_DIR/Security" ]
				then
					mv -f $INSTALL_DIR/Security $INSTALL_DIR/Security.old
				fi
			  echo "Copy security file from unison dir..."
			  execute_command "cp ../unison/Security $INSTALL_DIR/Security"
			fi
		fi
	fi
fi

if [ ! -f "$INSTALL_DIR/Security" ]
then
  echo "Creating security file..."
  execute_command "makesec -l Security.conf"
else
  echo "Skipping security file creation"
fi

# Set permission on security file
execute_command chown $MAEUSER $INSTALL_DIR/Security




# Create the useropts and create cpu definition in DB
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Patch: NO
if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then

   # Create the useropts for the master or backup master
   if [ "$TWS_CPUTYPE" = "MDM" -o "$TWS_CPUTYPE" = "BKM" ]
   then
       TWS_USERHOME=`$ACTIONTOOLS_DIR/twsUserHomeRetrieveAction.sh $MAEUSER`; export TWS_USERHOME
       if [ ! -d "$TWS_USERHOME/.TWS" ]
       then
           echo "create TWS_USERHOME DIR"
           mkdir -p "$TWS_USERHOME/.TWS"
       else
        echo "TWS_USERHOME DIR exists"
       fi
       echo "#                                                                           " >  $TWS_USERHOME/.TWS/useropts_$MAEUSER
       echo "# TWS useropts file defines credential attributes of the remote Workstation." >> $TWS_USERHOME/.TWS/useropts_$MAEUSER
       echo "#                                                                           " >> $TWS_USERHOME/.TWS/useropts_$MAEUSER
       echo "USERNAME = $MAEUSER                                                         " >> $TWS_USERHOME/.TWS/useropts_$MAEUSER
       echo "PASSWORD = \"$MAEPASSWORD\"                                                 " >> $TWS_USERHOME/.TWS/useropts_$MAEUSER
       chown $MAEUSER $TWS_USERHOME/.TWS
       chmod 700 $TWS_USERHOME/.TWS
       chown $MAEUSER $TWS_USERHOME/.TWS/useropts_$MAEUSER
       chmod 600 $TWS_USERHOME/.TWS/useropts_$MAEUSER
    fi



  # Create cpu in DB using composer
  if [ ! -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
  then
    if [ "$TWS_CPUTYPE" = "MDM" ]
    then
      if [ -f $INSTALL_DIR/cpudef_unix ]
       then
       echo "Updating DB file..."
            execute_command "composer -f $TWS_USERHOME/.TWS/useropts_$MAEUSER replace cpudef_unix"
              fi
       fi
  fi

fi


# *****************
# CLEAN ENVIRONMENT
# *****************


echo "Before Updating TWSRegistry.dat"


# TWSREGISTRY.DAT CLEANING *****
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Patch: NO


if [ ! -f "$TWSREGISTRYFILE" ]
then
  echo "Creating TWSRegistryFile..."
  echo " " > $TWSREGISTRYFILE
fi

# first try to add a row to catch error before cleaning action....
twsRegistryKey="/Tivoli/Workload_Scheduler/$MAEUSER"

# During patch installation sessions, the property FixpackName,previously inserted by the SPB, is taken out of the
# TWSRegistry.dat file and is correctly updated
#if [ -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
#then
#	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FixpackName $VERBOSE"
#	execute_command "$cmd"
#	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FixpackName=FP_TWS_${INST_INTERP}_${MAEUSER}.8.3.0.05 $VERBOSE"
#	execute_command "$cmd"
#fi

# Patch does not modify TWSRegistry entries, only patchversion
if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then
	# TWSREGISTRY.DAT DELETING *****
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_objectClass $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PackageName $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MajorVersion $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MinorVersion $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PatchVersion $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FeatureList $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ProductID $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ou $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_InstallationPath $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_UserOwner $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MaintenanceVersion $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FixpackName $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent $VERBOSE"
	execute_command "$cmd"
	
	# TWSREGISTRY.DAT ADDING   *****
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_objectClass=OU $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PackageName=FP_TWS_${INST_INTERP}_${MAEUSER}.8.3.0.05 $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MajorVersion=8 $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MinorVersion=3 $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PatchVersion= $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FeatureList= $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ProductID=TWS_ENGINE $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ou=$MAEUSER $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_InstallationPath=$INSTALL_DIR $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_UserOwner=$MAEUSER $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MaintenanceVersion= $VERBOSE"
	execute_command "$cmd"
	cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FixpackName=FP_TWS_${INST_INTERP}_${MAEUSER}.8.3.0.05 $VERBOSE"
	execute_command "$cmd"
fi

# Update Agent info in TWSRegistry.dat file
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: NO

if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then

cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent $VERBOSE"
execute_command "$cmd"
  
if [ "$TWS_CPUTYPE" = "SA" ]
then
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=FTA $VERBOSE"
  execute_command "$cmd"
fi

if [ "$TWS_CPUTYPE" = "FTA" ] 
then
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=FTA $VERBOSE"
  execute_command "$cmd"
fi

if [ "$TWS_CPUTYPE" = "MDM" ]
then 
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=MDM $VERBOSE"
  execute_command "$cmd"
fi

if [ "$TWS_CPUTYPE" = "BKM" ] 
then
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=BKM $VERBOSE"
  execute_command "$cmd"
fi

fi


# *** FIXPACK ONLY ***
# Scenario Fresh: NO
# Scenario Upgrade: NO
# Scenario Patch: YES

# SPB will execute this step
#  if [ -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
#  then
#    cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FixpackName=FP_TWS_${INST_INTERP}_$MAEUSER.8.3.0.01 $VERBOSE"
#    execute_command "$cmd"
#  fi


echo "After Updating TWSRegistry.dat"





# Verbose is activated only for SPB installation, in this case commit can't do the following...
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Patch: NO


if [ ! -f "$STATUSDIR/METHOD_CM.historyFile" -a ! -f $STATUSDIR/METHOD_TIER2.historyFile ]
then
  if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
  then
      cd "$SD_CLI_DIR"
      PATH="$BACKUPLOCALPATHVAR"
      . ./swd_env.sh

      #----- COMMIT LANG SPB ACTION -------------------------------------------

      ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT
      ACTION_TOOL_RET_COD=0

      LANG_PKG_NAME="TWS_LP_${MAEUSER}.8.3.0.05"
      INST_CMD_LINE="wdacptsp ${LANG_PKG_NAME}"

      # Call SPB script
      ACTION_TOOL_RET_STDOUT=`${INST_CMD_LINE}`
      ACTION_TOOL_RET_COD=$?

      if [ $ACTION_TOOL_RET_COD -ne 0 -a $ACTION_TOOL_RET_COD -ne 7 ]
      then
        ACTION_TOOL_RET_COD=1
      fi
      if [ $ACTION_TOOL_RET_COD -eq 7 ]
      then
        ACTION_TOOL_RET_COD=0
      fi

      # Print Debug Information
      echo "commitLangSPBAction"
      echo "$ACTION_TOOL_RET_STDOUT"

      # Action Result Handling
       if [ $ACTION_TOOL_RET_COD -ne 0 ]
       then
         echo "PROBLEMS FOUND"
      #   exit 1
       fi


      #----- END ACTION ------------------------------------------





      #----- COMMIT ENGINE SPB ACTION -------------------------------------------

      ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT
      ACTION_TOOL_RET_COD=0

      INST_PKG_NAME="FP_TWS_${INST_INTERP}_${MAEUSER}.8.3.0.05"
      INST_CMD_LINE="wdacptsp ${INST_PKG_NAME}"

      # Call SPB script
      ACTION_TOOL_RET_STDOUT=`${INST_CMD_LINE}`
      ACTION_TOOL_RET_COD=$?

      if [ $ACTION_TOOL_RET_COD -ne 0 -a $ACTION_TOOL_RET_COD -ne 7 ]
      then
        ACTION_TOOL_RET_COD=1
      fi
      if [ $ACTION_TOOL_RET_COD -eq 7 ]
      then
        ACTION_TOOL_RET_COD=0
      fi


      # Print Debug Information
      echo "commitEngineSPBAction"
      echo "$ACTION_TOOL_RET_STDOUT"

      # Action Result Handling
      if [ $ACTION_TOOL_RET_COD -ne 0 ]
      then
        echo "PROBLEMS FOUND"
      #   exit 1
      fi
   fi

      #----- END ACTION ------------------------------------------


# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Patch: YES

if [ -f "$MAIN_DIR/WCONVCAT/wconvcat_env.sh" -a ! -f "$STATUSDIR/METHOD_TIER2.historyFile" ]
then
      #----- WCONVCAT FIX FOR CM ACTION -------------------------------------------

      ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT
      ACTION_TOOL_RET_COD=0

      cd "$SD_CLI_DIR"
      PATH="$BACKUPLOCALPATHVAR"
      . ./swd_env.sh

      cd "$SD_WCONVCAT_DIR"
      . ./wconvcat_env.sh

      INST_CMD_LINE="wconvcat -d"

      # Call SPB script
      ACTION_TOOL_RET_STDOUT=`${INST_CMD_LINE}`
      ACTION_TOOL_RET_COD=$?

      # Print Debug Information
      echo "fixCMCatalogAction"
      echo "$ACTION_TOOL_RET_STDOUT"

      # Action Result Handling
      if [ $ACTION_TOOL_RET_COD -ne 0 ]
      then
        echo "wconvcat: PROBLEMS FOUND"
      #   exit 1
      fi


      #----- END ACTION ------------------------------------------
fi

  PATH="$BACKUPLOCALPATHVAR"
  cd "$MAIN_DIR"
  
fi


if [ -f "$STATUSDIR/METHOD_TIER2.historyFile" ]
 then
      # Print Debug Information
      echo "commitEngineSPBAction"
fi                                                                         
# CLEANING ACTION

# Remove Symphony only promote scenario

# Scenario Fresh: NO
# Scenario Upgrade: NO
# Scenario Patch: NO

if [ -f "$STATUSDIR/FLOW_PROMOTE.historyFile" ]
then

  if [  -f $INSTALL_DIR/Symphony ]
  then
  if [ "$TWS_CPUTYPE" = "MDM" ]
  then
    echo "Removing Symphony"
    rm -rf $INSTALL_DIR/Symphony
  fi
  if [ "$TWS_CPUTYPE" = "BKM" ]
  then
    echo "Removing Symphony"
    rm -rf $INSTALL_DIR/Symphony
  fi
  fi
fi


# Clean binaries for different agents
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Patch: YES


REMOVEDELTA_MASTER="false"

if [ "$TWS_CPUTYPE" = "SA" ]
then
  REMOVEDELTA_MASTER="true"
fi
if [ "$TWS_CPUTYPE" = "FTA" ]
then
  REMOVEDELTA_MASTER="true"
fi

if [ "$REMOVEDELTA_MASTER" = "true" ]
then
  echo "Removing delta Master file..."

  rm -f $INSTALL_DIR/JnextPlan
  rm -f $INSTALL_DIR/MakePlan
  rm -f $INSTALL_DIR/SwitchPlan
  rm -f $INSTALL_DIR/CreatePostReports
  rm -f $INSTALL_DIR/UpdateStats
  rm -f $INSTALL_DIR/ResetPlan
  rm -f $INSTALL_DIR/CheckPrerequisites
  rm -f $INSTALL_DIR/Sfinal
  rm -f $INSTALL_DIR/cpudef_unix
  rm -f $INSTALL_DIR/rm_Symphony

  rm -f $INSTALL_DIR/config/JnextPlan
  rm -f $INSTALL_DIR/config/MakePlan
  rm -f $INSTALL_DIR/config/SwitchPlan
  rm -f $INSTALL_DIR/config/ResetPlan
  rm -f $INSTALL_DIR/config/CreatePostReports
  rm -f $INSTALL_DIR/config/UpdateStats
  rm -f $INSTALL_DIR/config/Sfinal


  rm -f $INSTALL_DIR/demo/skedlist
  rm -f $INSTALL_DIR/demo/sgl
  rm -f $INSTALL_DIR/demo/sarec
  rm -f $INSTALL_DIR/demo/sapay
  rm -f $INSTALL_DIR/demo/jgljob2
  rm -f $INSTALL_DIR/demo/jgljob1
  rm -f $INSTALL_DIR/demo/jdemojcl
  rm -f $INSTALL_DIR/demo/jarjob2
  rm -f $INSTALL_DIR/demo/jarjob1
  rm -f $INSTALL_DIR/demo/japjob2
  rm -f $INSTALL_DIR/demo/japjob1
  rm -f $INSTALL_DIR/demo/expskedlist
  rm -f $INSTALL_DIR/demo/expsetup
  rm -f $INSTALL_DIR/demo/expgl
  rm -f $INSTALL_DIR/demo/exparec
  rm -f $INSTALL_DIR/demo/expapay
  rm -f $INSTALL_DIR/demo/demosetup
  rm -f $INSTALL_DIR/demo/demonetcpu
  rm -f $INSTALL_DIR/demo/democpu
  rm -fr $INSTALL_DIR/demo

	rm -fr $INSTALL_DIR/schedForecast
	rm -fr $INSTALL_DIR/schedlog
	rm -fr $INSTALL_DIR/schedTrial

  rm -f $INSTALL_DIR/bin/sorter
  rm -f $INSTALL_DIR/bin/composer
  rm -f $INSTALL_DIR/bin/archiver
  rm -f $INSTALL_DIR/bin/logman
  rm -f $INSTALL_DIR/bin/makecal
  rm -f $INSTALL_DIR/bin/planman
  rm -f $INSTALL_DIR/bin/optman
  rm -f $INSTALL_DIR/bin/stageman  
  rm -f $INSTALL_DIR/bin/composer81
  rm -f $INSTALL_DIR/bin/composer821
  rm -f $INSTALL_DIR/bin/tws_launch_archiver.pl
  rm -f $INSTALL_DIR/bin/migrutility
  rm -f $INSTALL_DIR/bin/getmozart
  rm -f $INSTALL_DIR/bin/db_backup.sh
  rm -f $INSTALL_DIR/bin/datamigrate  

  #Reports only for master
  rm -f $INSTALL_DIR/bin/r11xtr
  rm -f $INSTALL_DIR/bin/rep1
  rm -f $INSTALL_DIR/bin/rep11
  rm -f $INSTALL_DIR/bin/rep2
  rm -f $INSTALL_DIR/bin/rep3
  rm -f $INSTALL_DIR/bin/rep4a
  rm -f $INSTALL_DIR/bin/rep4b
  rm -f $INSTALL_DIR/bin/rep7
  rm -f $INSTALL_DIR/bin/rep8
  rm -f $INSTALL_DIR/bin/report1
  rm -f $INSTALL_DIR/bin/report11
  rm -f $INSTALL_DIR/bin/report2
  rm -f $INSTALL_DIR/bin/report3
  rm -f $INSTALL_DIR/bin/report4a
  rm -f $INSTALL_DIR/bin/report4b
  rm -f $INSTALL_DIR/bin/report7
  rm -f $INSTALL_DIR/bin/report8
  rm -f $INSTALL_DIR/bin/reporter
  rm -f $INSTALL_DIR/bin/reptr
  rm -f $INSTALL_DIR/bin/rextract
  rm -f $INSTALL_DIR/bin/xref
  rm -f $INSTALL_DIR/bin/xrxtrct

fi

if [ "$REMOVEDELTA_MASTER" = "false" ]
then
  echo "Removing cluster files from Master..."
  rm -fr $INSTALL_DIR/cluster
  rm -f $INSTALL_DIR/catalog/C/cluster.cat
  rm -f $INSTALL_DIR/catalog/de/cluster.cat
  rm -f $INSTALL_DIR/catalog/es/cluster.cat
  rm -f $INSTALL_DIR/catalog/fr/cluster.cat
  rm -f $INSTALL_DIR/catalog/it/cluster.cat
  rm -f $INSTALL_DIR/catalog/ja/cluster.cat
  rm -f $INSTALL_DIR/catalog/ko/cluster.cat
  rm -f $INSTALL_DIR/catalog/pt_BR/cluster.cat
  rm -f $INSTALL_DIR/catalog/zh_CN/cluster.cat
  rm -f $INSTALL_DIR/catalog/zh_TW/cluster.cat
fi
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Patch: NO

if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then

  echo "Removing old TWS version files..."

  # File no loger used by TWS 8.3: START
  rm -f $INSTALL_DIR/Jnextday
  rm -f $INSTALL_DIR/config/Jnextday
  rm -f $INSTALL_DIR/config/netman_localopt
  rm -f $INSTALL_DIR/config/netman_NEtconf
  rm -f $INSTALL_DIR/config/netman_StartUp

  rm -f $INSTALL_DIR/bin/schedulr
  rm -f $INSTALL_DIR/bin/compiler
  rm -f $INSTALL_DIR/bin/dbexpand
  rm -f $INSTALL_DIR/bin/dbinfo
  rm -f $INSTALL_DIR/bin/gsort

  rm -f $INSTALL_DIR/mozart/calendars
  rm -f $INSTALL_DIR/mozart/calendars.KEY
  rm -f $INSTALL_DIR/mozart/jobs
  rm -f $INSTALL_DIR/mozart/jobs.KEY
  rm -f $INSTALL_DIR/mozart/jobs.sched.KEY
  rm -f $INSTALL_DIR/mozart/prompts
  rm -f $INSTALL_DIR/mozart/prompts.KEY
  rm -f $INSTALL_DIR/mozart/resources
  rm -f $INSTALL_DIR/mozart/resources.KEY
  rm -f $INSTALL_DIR/mozart/mastsked
  rm -f $INSTALL_DIR/mozart/mastsked.KEY
# rm -f $INSTALL_DIR/mozart/globalopts <--- It's not possible to remove it because it's still used
# File no loger used by TWS 8.3: END

  rm -f $INSTALL_DIR/bin/gcomposer
  rm -f $INSTALL_DIR/bin/gcomposer.vhs
  rm -f $INSTALL_DIR/bin/gcomposer.vr
  rm -f $INSTALL_DIR/bin/gconman
  rm -f $INSTALL_DIR/bin/gconman.vhs
  rm -f $INSTALL_DIR/bin/gconman.vr
  rm -f $INSTALL_DIR/bin/gjdlb
  rm -f $INSTALL_DIR/bin/gjdlb.vr
  rm -f $INSTALL_DIR/bin/gmaestro
  rm -f $INSTALL_DIR/bin/gmaestro.vr

  rm -f $INSTALL_DIR/bin/jhxtract
  rm -f $INSTALL_DIR/bin/rmatjob
  rm -f $INSTALL_DIR/bin/startcpu
  rm -f $INSTALL_DIR/bin/stop
  rm -f $INSTALL_DIR/bin/symread
  rm -f $INSTALL_DIR/bin/tellop
  rm -f $INSTALL_DIR/bin/unisubmit

  rm -f $INSTALL_DIR/bin/vgalaxy2.vr
  rm -f $INSTALL_DIR/bin/vhelpsrv
  rm -f $INSTALL_DIR/bin/vhelpsrv.vhs
  rm -f $INSTALL_DIR/bin/vhelpsrv.vr
  rm -f $INSTALL_DIR/bin/visualm
  rm -f $INSTALL_DIR/bin/visualm.vhs
  rm -f $INSTALL_DIR/bin/visualm.vr
  rm -f $INSTALL_DIR/bin/xcomposer
  rm -f $INSTALL_DIR/bin/xcomposer.vr
  rm -f $INSTALL_DIR/bin/xconman
  rm -f $INSTALL_DIR/bin/xconman.vr
  rm -f $INSTALL_DIR/bin/xmaestro
  rm -f $INSTALL_DIR/bin/xmaestro.vr

# Old TWS8.2 uninstall dir
  rm -fR ${INSTALL_DIR}/_uninst
  rm -f $INSTALL_DIR/cpudef_unix
  rm -f $INSTALL_DIR/rm_Symphony

fi


# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Patch: NO
# Cleaning components file
if [ -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
then
  if [ -f "$UNISON_COMPONENT_FILE" ]
  then
    `$ACTIONTOOLS_DIR/TWSupdate_file -delRow "$UNISON_COMPONENT_FILE" ${MAEUSER}`
  fi
fi

rm -f $INSTALL_DIR/twsRestore.sh
rm -rf *old
rm -f $INSTALL_DIR/*.old
rm -f $INSTALL_DIR/mozart/*.old
rm -f $INSTALL_DIR/*.bck
rm -f $INSTALL_DIR/mozart/*.bck
rm -f $INSTALL_DIR/Tbsm/TbsmAdapter/*.bck
rm -f $STATUSDIR/*.historyFile

# copying the useropts file in the directory .TWS under the home of the installer (root)
if [ "$TWS_CPUTYPE" = "MDM" -o "$TWS_CPUTYPE" = "BKM" ]
then
	if [ ! -d "$HOME/.TWS" ]
	then
	    echo "create TWS_ROOTHOME DIR"
	    mkdir -p "$HOME/.TWS"
	else
		echo "TWS_ROOTHOME DIR exists"
	fi
	cp $TWS_USERHOME/.TWS/useropts_$MAEUSER $HOME/.TWS
fi

echo "Commit exited successfully"
exit 0

