#!/bin/sh
####################################################################
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
# 5698-WSH
# (C) Copyright IBM Corp. 1998, 2006 All Rights Reserved.
###################################################################

#------------ Stop Function ------------

#------------ parameter   ------------
#TwsStopAction.sh  -check / -stop
#		  <USER>
#                 <tws home path>
#		  <file containing the list of executable files>
# 		  -verbose to print catalog error message

#------------ exit value  ------------
#  0     TWS processes are not running
#  1     TWS processes still running
#  2     "The file containing the list of executable files is missing"

#on stderr YUO can find warning, info message and error message from catalog
#on stdout YUO can find ,if there are ptws processes running, the process name + PID

#------------ Verify if is required only the version -------
#------------ Needed to fix build break --------------------


Script_version=" 1.8 "

if [ $# -eq 1 ]
then
  if [ "$1" = "-v" -o "$1" = "-V" ]
  then
    echo "$Script_version"
    exit 0
  fi
fi


DO_OPTION="$1"
MAEUSER="$2";export MAEUSER
INSTALL_DIR="$3";export INSTALL_DIR
tws_files_list="$4"
verbose="$5"


OS=`uname -s`;export OS
mailman=""
clagent=""



#
# This function checks if the autotrace system is on
stop_trace_system()
{
        # If we are updating we can use current trace commands to stop
        if [ -x "$INSTALL_DIR/trace/atctl" ]
        then
            # Stop trace and remove all channels
            `"$INSTALL_DIR/trace/atctl" off TWS all  > /dev/null 2>&1`
            `"$INSTALL_DIR/trace/atctl" remove all  > /dev/null 2>&1`
#	    echo "Info: Autotrace process is stopped."
    fi
    # Free dynamic libraries for AIX
    if [ "$OS" = "AIX" ]
    then
        slibclean
    fi

    return 0
}





stop_connector()
{

if [ -f /etc/Tivoli/setup_env.sh ]
then
    # Source tivoli environment
    . /etc/Tivoli/setup_env.sh

	# Check if the bin dir created installing the TWSConnector it exists.
    if [ -d $BINDIR/Maestro/bin ]
    then
        #  Trap ABRT signal to prevent Jnextday from terminating in some cases
        trap  '' ABRT
		#
		#Stop all mapper servers so that they all open new symphony.
		#
#		echo "Info: trying to Stop connector"

    if [ -f $INSTALL_DIR/bin/wmaeutil.sh ]
    then
      $INSTALL_DIR/bin/wmaeutil.sh  ALL -stop
      if [ $? -ne 0 ]
      then
		echo "WARNING. Unable to stop ALL Connectors." >&2
                return 1
      fi
    fi
     #  Reset the original value for RedHat 4.0 use a different usage of trap defect 185895
  if [ "$OS" = "Linux" ]
    then
        trap - ABRT  2>&1
    else
   	trap ABRT 2>&1
 	fi
    fi
fi
  return 0
}






stop_twsinstance()
{

# IY59425:  check if mailman and clagent still active
platform=`uname`
#if [ "$platform" = "DYNIX/ptx" ]
#then
#fusertest=`type fuser | awk '{print $3}'`
#else
#fusertest=`which fuser 2>/dev/null`
#fi

case "$platform" in

  DYNIX/ptx) 
    fusertest=`type fuser | awk '{print $3}'`
    ;;
 
  OSF1)
    fusertest=`which fuser 2>/dev/null`
    if [ "$fusertest" = "" ]
    then
      fusertest=`type fuser | tr '(' ' ' | tr ')' ' ' | tr '\t' ' ' | tr -s "" " " | sed 's/^ *//g' | cut -d' ' -f 4`
    fi
    ;;

  *)
    fusertest=`which fuser 2>/dev/null`
    ;;
 
esac

if [ "$fusertest" = "" ]
then
  echo "Warning: unable to check if there are mailman and clagent process active..\n" >&2
fi

if [ -f $fusertest ]
then

  case "$platform" in

     AIX) mailman=`fuser -xf $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9]e$" 2>&1`
	  clagent=`fuser -xf $INSTALL_DIR/bin/clagent 2>&1 | grep "[0-9]e$" 2>&1`
          ;;

     HP-UX) mailman=`fuser $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9][m,t]$" 2>&1`
	    clagent=`fuser $INSTALL_DIR/bin/clagent 2>&1 | grep "[0-9][m,t]$" 2>&1`
            ;;



     Linux) mailman=`fuser $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9]e$" 2>&1`
	    clagent=`fuser $INSTALL_DIR/bin/clagent 2>&1 | grep "[0-9]e$" 2>&1`
            ;;

     SunOS) mailman=`fuser $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9]tm$" 2>&1`
	    clagent=`fuser $INSTALL_DIR/bin/clagent 2>&1 | grep "[0-9]tm$" 2>&1`
            ;;

     IRIX64) mailman=`fuser $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9]tm$" 2>&1`
	      ;;
     OSF1) mailman=`fuser $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9]tm$" 2>&1`
	      ;;
     DYNIX/ptx) mailman=`fuser $INSTALL_DIR/bin/mailman 2>&1 | grep "[0-9]tm$" 2>&1` 
            ;;
     *) echo "Warning: unable to check if there are mailman and clagent process active..\n" >&2
     ;;

  esac

else
  echo "Warning: unable to check if there are mailman and clagent process active..\n" >&2
fi


#
# Try to stop all actives processes of previous installation

if [ -x "$INSTALL_DIR/bin/conman" ] && [ -f "$INSTALL_DIR/Symphony" ]
then
# IY59425: unlink only if mailman active
      if [ ! -z "$mailman" ]
      then
#        echo "Unlinking..."
        # IY59425: unlink only cpu in the domain
      	# su $MAEUSER -c "$INSTALL_DIR/bin/conman \"unlink @!@;noask\" "
          su $MAEUSER -c "$INSTALL_DIR/bin/conman \"unlink @;noask\" " 2>&1
      	  su $MAEUSER -c "$INSTALL_DIR/bin/conman \"stop\" " 2>&1
      fi

      # IY59425: stop clagent if active
      if [ ! -z "$clagent" ]
      then
      	su $MAEUSER -c "$INSTALL_DIR/bin/conman \"clagent_stop\" " 2>&1
      fi

#     echo "Stopping..."
     su $MAEUSER -c "$INSTALL_DIR/bin/conman \"shut;wait\" " >2
fi

# Netman can be killed...
if [ -f $INSTALL_DIR/pids/NETMAN.pid ]
then
      NETMAN_PID=`cat $INSTALL_DIR/pids/NETMAN.pid`

      ps -p $NETMAN_PID | grep netman
      ACT_MAE_PRC=$?
      
      if [ $ACT_MAE_PRC -eq 0 ]
      then
          kill -9 $NETMAN_PID
      	  if [ $? -ne 0 ]
          then
           echo "WARNING. Unable to kill $INSTALL_DIR/bin/netman process." >&2
           echo "The $INSTALL_DIR/bin/netman prosess is still active."     >&2
           echo "All TWS processes must be down exiting"   >&2
           return 1
           fi
      fi
#      echo "Info: $INSTALL_DIR/bin/netman process is killed."
fi
  return 0
}


# this function check and PRINT tws processes still active
ViewTWSinstance()
{

platform=`uname`

case "$platform" in

  DYNIX/ptx) 
    fusertest=`type fuser | awk '{print $3}'`
    ;;
 
  OSF1)
    fusertest=`which fuser 2>/dev/null`
    if [ "$fusertest" = "" ]
    then
      fusertest=`type fuser | tr '(' ' ' | tr ')' ' ' | tr '\t' ' ' | tr -s "" " " | sed 's/^ *//g' | cut -d' ' -f 4`
    fi
    ;;

  *)
    fusertest=`which fuser 2>/dev/null`
    ;;
 
esac

if [ "$fusertest" = "" ]
then
  echo "Warning: unable to check if there are TWS active processes..\n" >&2
  return 0
fi

if [ -f $fusertest ]
then

  case "$platform" in

     AIX)
     
        # Free dynamic libraries for AIX
        slibclean
    
          for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
		   fuser -xf "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]e$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	  done
          ;;

     HP-UX) for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
   		   fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9][m,t]$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	    done
            ;;

     Linux) for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
                if [ "$PATH_OF_FILE" = "bin" ]
		then
		   fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]e$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	    done

            ;;

     SunOS) for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
		    fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	    done
      
            ;;
          
     IRIX64) for var in $tws_files_list; do
                 PATH_OF_FILE="`dirname $var`"
		 if [ "$PATH_OF_FILE" = "bin" ]
		 then
		     fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		 fi
	     done

             ;;


     OSF1) for var in $tws_files_list; do
                 PATH_OF_FILE="`dirname $var`"
		 if [ "$PATH_OF_FILE" = "bin" ]
		 then
		     fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		 fi
	     done

             ;;
     DYNIX/ptx) for var in $tws_files_list; do
                 PATH_OF_FILE="`dirname $var`"
		 if [ "$PATH_OF_FILE" = "bin" ]
		 then
		     fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		 fi
	     done
             ;;

      *) echo "Warning: unable to check if there are TWS active processes.." >&2
        ;;

  esac
       if [ -s "/tmp/twsp.tmp.$$" ]
       then

#          echo "ERROR: TWS processes still active:"
          echo ""
          sed -e "s/\([0-9]\)\([0-9]*\)\([a-zA-Z]*\)/\1\2/g" /tmp/twsp.tmp.$$
          echo ""
#          echo "Please, be sure TWS processes are stopped before restarting the installation"
#          echo "`cat /tmp/twsp.tmp.$$`"

          rm -f /tmp/twsp.tmp.$$
          return 1
       fi

# Sometimes fuser is not working well
if [ -f $INSTALL_DIR/pids/NETMAN.pid ]
then
      NETMAN_PID=`cat $INSTALL_DIR/pids/NETMAN.pid`

      ps -p $NETMAN_PID | grep netman
      ACT_MAE_PRC=$?
            
      if [ $ACT_MAE_PRC -eq 0 ]
      then
          echo "Netman process found using ps -u $MAEUSER | grep netman"
          return 1
      fi
fi

else
  echo "Warning: unable to check if there are TWS active processes..\n" >&2
fi

return 0
}




# this function only check if tws processes still active

checkTWSinstance()
{
platform=`uname`
#if [ "$platform" = "DYNIX/ptx" ]
#then
#fusertest=`type fuser | awk '{print $3}'`
#else
#fusertest=`which fuser 2>/dev/null`
#fi

case "$platform" in

  DYNIX/ptx) 
    fusertest=`type fuser | awk '{print $3}'`
    ;;
 
  OSF1)
    fusertest=`which fuser 2>/dev/null`
    if [ "$fusertest" = "" ]
    then
      fusertest=`type fuser | tr '(' ' ' | tr ')' ' ' | tr '\t' ' ' | tr -s "" " " | sed 's/^ *//g' | cut -d' ' -f 4`
    fi
    ;;

  *)
    fusertest=`which fuser 2>/dev/null`
    ;;
 
esac

if [ "$fusertest" = "" ]
then
  echo "Warning: unable to check if there are TWS active processes..\n" >&2
  return 0
fi

if [ -f $fusertest ]
then

  case "$platform" in

     AIX)

        # Free dynamic libraries for AIX
        slibclean
             
          for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
		    fuser -xf "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]e$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	  done
          ;;

     HP-UX) for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
		   fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9][m,t]$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	    done
            ;;

     Linux)
           for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
		   fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]e$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
           done

            ;;

     SunOS) for var in $tws_files_list; do
                PATH_OF_FILE="`dirname $var`"
		if [ "$PATH_OF_FILE" = "bin" ]
		then
		    fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		fi
	    done

            ;;

     IRIX64) for var in $tws_files_list; do
                 PATH_OF_FILE="`dirname $var`"
		 if [ "$PATH_OF_FILE" = "bin" ]
		 then
		     fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		 fi
	     done

             ;;


     OSF1) for var in $tws_files_list; do
                 PATH_OF_FILE="`dirname $var`"
		 if [ "$PATH_OF_FILE" = "bin" ]
		 then
		     fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		 fi
	     done

             ;;

     DYNIX/ptx) for var in $tws_files_list; do
                 PATH_OF_FILE="`dirname $var`"
		 if [ "$PATH_OF_FILE" = "bin" ]
		 then
		     fuser "$INSTALL_DIR/$var" 2>&1 | grep "[0-9]tm$" >> /tmp/twsp.tmp.$$ 2>&1
		 fi
	     done

             ;;

     *) echo "Warning: unable to check if there are TWS active processes.." >&2
        ;;

  esac
       if [ -s "/tmp/twsp.tmp.$$" ]; then
          rm -f /tmp/twsp.tmp.$$
          return 1
       fi
      
# Sometimes fuser is not working well
if [ -f $INSTALL_DIR/pids/NETMAN.pid ]
then
      NETMAN_PID=`cat $INSTALL_DIR/pids/NETMAN.pid`

      ps -p $NETMAN_PID | grep netman
      ACT_MAE_PRC=$?
            
      if [ $ACT_MAE_PRC -eq 0 ]
      then
          echo "Netman process found using ps -u $MAEUSER | grep netman"
          return 1
      fi
fi

		
else
  echo "Warning: unable to check if there are TWS active processes..\n" >&2
fi

return 0
}



#### MAIN ####


if [ ! -f ${tws_files_list} ]
  then
   if [ "$verbose" = "-verbose" ]
     then
    echo "xxxx #The list file ${tws_files_list} is missing." >&2
    echo "Check its presence and then run twsinst again." >&2
   fi
    exit 2
  else
  echo " "
fi

tws_files_list="`cat ${tws_files_list}`"

if [ "$DO_OPTION" = "-stop" ]
then

#check Tws process before stopping
checkTWSinstance
ACTION_TOOL_RET_COD=$?
if [ $ACTION_TOOL_RET_COD -ne 0 ]
then
  echo ""
else
  exit 0
fi

#try to stop tws instance and wait
stop_trace_system
stop_twsinstance
sleep 5

#check Tws process (wait if running else exit)
checkTWSinstance
ACTION_TOOL_RET_COD=$?
# Second Time
if [ $ACTION_TOOL_RET_COD -ne 0 ]
then
  sleep 5
else
  exit 0
fi

#check Tws process (wait if running else exit)
checkTWSinstance
ACTION_TOOL_RET_COD=$?
# Third Time
if [ $ACTION_TOOL_RET_COD -ne 0 ]
then
  sleep 5
else
  exit 0
fi

fi
#view Tws process (on stdout print processes if running else exit with 0)

ViewTWSinstance
ACTION_TOOL_RET_COD=$?
if [ $ACTION_TOOL_RET_COD -ne 0 ]
then
  exit 1
else
  exit 0
fi


